@@ -6,17 +6,19 @@
 #![warn(missing_docs)]
 
 #[cfg(feature = "clipboard")]
-use clipboard::{ClipboardContext, ClipboardProvider};
+use copypasta::{ClipboardContext, ClipboardProvider};
 use egui::{
     math::{pos2, vec2},
     CtxRef,
 };
 use egui::{paint::ClippedShape, Key};
+use winit::dpi::PhysicalSize;
 use winit::event::VirtualKeyCode::*;
 use winit::event::WindowEvent::*;
 use winit::event::{Event, ModifiersState, VirtualKeyCode};
 
 /// Configures the creation of the `Platform`.
+#[derive(Debug, Default)]
 pub struct PlatformDescriptor {
     /// Width of the window in physical pixel.
     pub physical_width: u32,
@@ -101,6 +103,14 @@ impl Platform {
                 window_id: _window_id,
                 event,
             } => match event {
+                // Resize with 0 width and height is used by winit to signal a minimize event on Windows.
+                // See: https://github.com/rust-windowing/winit/issues/208
+                // There is nothing to do for minimize events, so it is ignored here. This solves an issue where
+                // egui window positions would be changed when minimizing on Windows.
+                Resized(PhysicalSize {
+                    width: 0,
+                    height: 0,
+                }) => {}
                 Resized(physical_size) => {
                     self.raw_input.screen_rect = Some(egui::Rect::from_min_size(
                         Default::default(),
